@@ -5,7 +5,7 @@ use version;
 use Carp qw/longmess/;
 use Data::Dumper qw/Dumper/;
 
-our $VERSION = version->new('0.1.6');
+our $VERSION = version->new('0.1.7');
 
 my $last;
 
@@ -50,8 +50,8 @@ sub fatal {
 sub _log {
     my ($self, $level, @message) = @_;
     $self = $last if !ref $self;
-    $message[0] = Dumper $message[0] if @message == 1 && ref $message[0];
-    chomp $message[-1] if $message[-1];
+    $message[0] = Dumper $message[0] if @message == 1 && ( ref $message[0] || !defined $message[0] );
+    chomp $message[-1];
     print {$self->fh} localtime() . " [$level] ", join ' ', @message, "\n";
     return;
 }
@@ -66,7 +66,7 @@ Data::Context::Log - Simple Log object helper
 
 =head1 VERSION
 
-This documentation refers to Data::Context::Log version 0.0.1
+This documentation refers to Data::Context::Log version 0.1.7
 
 =head1 SYNOPSIS
 
